@@ -130,7 +130,7 @@ class Env(BaseModel):
 
     if path_exists(python_path):
         env_src = read_text(python_path)
-        if env_init_src in python_path:
+        if env_init_src in env_src:
             env_src = env_init_src.split(env_init_src,1)[1]
             result += f"\n{env_src}"
     return result
